<?php
/************************************************************************
 * MXChange v0.2.1                                    Start: 12/03/2004 *
 * ===============                              Last change: 12/13/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : theme-manager.php                                *
 * -------------------------------------------------------------------- *
 * Short description : Theme manager                                    *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Themen-Manager                                   *
 * -------------------------------------------------------------------- *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2008 by Roland Haeder                           *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	$INC = substr(dirname(__FILE__), 0, strpos(dirname(__FILE__), "/inc") + 4) . "/security.php";
	require($INC);
}

function THEME_SELECTION_BOX($mod, $act, $wht, $result) {
	// Construction URL
	$FORM = "{!URL!}/modules.php?module=".$mod;
	if (!empty($act)) $FORM .= "&amp;action=".$act;
	if (!empty($wht))   $FORM .= "&amp;what=".$wht;
	define('__FORM_VALUE', $FORM);

	// Initialize array
	$THEMES = array(
		'theme_unix'   => array(), // Unix name from filesystem
		'theme_name'   => array()  // Title
	);

	// Load all themes
	while (list($theme) = SQL_FETCHROW($result)) {
		// Load it's theme.php file
		$INC = sprintf("theme/%s/theme.php", SQL_ESCAPE($theme));
		if (INCLUDE_READABLE($INC)) {
			// And save all data in array
			LOAD_INC($INC);
			$THEMES['theme_unix'][] = $theme;
			$THEMES['theme_name'][] = $THEME_NAME;
		} // END - if
	} // END - while

	// Sort whole array by title
	array_pk_sort($THEMES, array("theme_name"));

	// Construct selection form for the box template
	$OUT = "";
	foreach ($THEMES['theme_unix'] as $key => $theme) {
		$OUT .= "  <option value=\"".$theme."\"";
		if ($theme == GET_CURR_THEME()) $OUT .= " selected=\"selected\"";
		$OUT .= ">".$THEMES['theme_name'][$key]."</option>\n";
	} // END - foreach

	// Return generated selection
	define('__THEME_SELECTION_OPTIONS', $OUT);
	$OUT = LOAD_TEMPLATE("theme_select_form", true);
	return $OUT;
}

// Get version from name
function THEME_GET_VERSION ($name) {
	global $cacheArray;

	// Is the extension "theme" installed?
	if (!EXT_IS_ACTIVE("theme")) {
		// Then abort here
		return "!.!";
	} // END - if

	// Default version "number"
	$cver = "?.?";

	// Is the cache entry there?
	if (isset($cacheArray['themes']['theme_ver'][$name])) {
		// Get the version from cache
		$cver = $cacheArray['themes']['theme_ver'][$name];

		// Count up
		incrementConfigEntry('cache_hits');
	} elseif (GET_EXT_VERSION("cache") != "0.1.8") {
		// Load version from database
		$result = SQL_QUERY_ESC("SELECT theme_ver FROM `{!_MYSQL_PREFIX!}_themes` WHERE theme_path='%s' LIMIT 1",
			array($name), __FILE__, __LINE__);

		// Entry found?
		if (SQL_NUMROWS($result) == 1) {
			// Fetch data
			list($cver) = SQL_FETCHROW($result);
		} // END - if

		// Free result
		SQL_FREERESULT($result);
	}

	// Return version
	return $cver;
}

// Checks wether a theme is found in db
function THEME_CHECK_EXIST ($name) {
	// Get theme and is it not nul?
	return (THEME_GET_ID($name) > 0);
}

// Checks if a theme is active
function THEME_IS_ACTIVE ($name) {
	global $cacheArray;

	// Is the extension "theme" installed?
	if (!EXT_IS_ACTIVE("theme")) {
		// Then abort here
		return false;
	} // END - if

	// Default is nothing active
	$active = false;

	// Is the cache entry there?
	if (isset($cacheArray['themes']['theme_active'][$name])) {
		// Get the version from cache
		$active = ($cacheArray['themes']['theme_active'][$name] == "Y");

		// Count up
		incrementConfigEntry('cache_hits');
	} elseif (GET_EXT_VERSION("cache") != "0.1.8") {
		// Check if current theme is already imported or not
		$result = SQL_QUERY_ESC("SELECT theme_active FROM `{!_MYSQL_PREFIX!}_themes` WHERE theme_path='%s' AND theme_active='Y' LIMIT 1",
			array($name), __FILE__, __LINE__);

		// Is the theme active and installed?
		$active = (SQL_NUMROWS($result) == 1);

		// Free result
		SQL_FREERESULT($result);
	}

	// Return result
	return $active;
}

// Gets current human-readable theme name
function GET_CURR_THEME_NAME () {
	global $cacheArray;

	// Is the extension "theme" installed?
	if (!EXT_IS_ACTIVE("theme")) {
		// Then abort here
		return "default";
	} // END - if

	// Get the Uni* name
	$name = GET_CURR_THEME();

	// Is the cache entry there?
	if (isset($cacheArray['themes']['theme_name'][$name])) {
		// Get the version from cache
		$name = $cacheArray['themes']['theme_name'][$name];

		// Count up
		incrementConfigEntry('cache_hits');
	} elseif (GET_EXT_VERSION("cache") != "0.1.8") {
		// Check if current theme is already imported or not
		$result = SQL_QUERY_ESC("SELECT theme_name FROM `{!_MYSQL_PREFIX!}_themes` WHERE theme_path='%s' AND theme_active='Y' LIMIT 1",
			array($name), __FILE__, __LINE__);

		// Load theme name
		list($name) = SQL_FETCHROW($result);

		// Free result
		SQL_FREERESULT($result);
	}

	// Return name
	return $name;
}

// Initialize variables
$currTheme = GET_CURR_THEME();

// Check if new theme is selcted
if ((!empty($_POST['new_theme'])) && ($_POST['new_theme'] != $currTheme)) {
	// Set new theme for guests
	$newTheme = $_POST['new_theme'];

	// Change to new theme
	set_session('mxchange_theme', $newTheme);

	// Remove current from array and set new
	$theme = sprintf("%stheme/%s/theme.php", constant('PATH'), $currTheme);
	unset($INC_POOL[array_search($theme, $INC_POOL)]);
	$INC_POOL[] = sprintf("%stheme/%s/theme.php", constant('PATH'), $newTheme);
} // END - if

//
?>
